pub struct RequestType { /* private fields */ }Expand description
RequestType bitfields for the setup packet.
This type encodes three separate multi-bit fields packed into a single byte (USB 2.0 spec Table 9-2):
- Recipient (bits 0–4):
RECIPIENT_DEVICE,RECIPIENT_INTERFACE,RECIPIENT_ENDPOINT,RECIPIENT_OTHER - Type (bits 5–6):
TYPE_STANDARD,TYPE_CLASS,TYPE_VENDOR,TYPE_RESERVED - Direction (bit 7):
OUT,IN
Combine exactly one value from each group with |. Do not OR values
within the same group (e.g. RECIPIENT_INTERFACE | RECIPIENT_ENDPOINT is invalid).
Implementations
Sourceimpl RequestType
impl RequestType
Sourcepub const RECIPIENT_DEVICE: Self
pub const RECIPIENT_DEVICE: Self
The request is intended for the entire device.
Sourcepub const RECIPIENT_INTERFACE: Self
pub const RECIPIENT_INTERFACE: Self
The request is intended for an interface.
Sourcepub const RECIPIENT_ENDPOINT: Self
pub const RECIPIENT_ENDPOINT: Self
The request is intended for an endpoint.
Sourcepub const RECIPIENT_OTHER: Self
pub const RECIPIENT_OTHER: Self
The recipient of the request is unspecified.
Sourcepub const TYPE_STANDARD: Self
pub const TYPE_STANDARD: Self
The request is a standard USB request.
Sourcepub const TYPE_CLASS: Self
pub const TYPE_CLASS: Self
The request is a class-specific request.
Sourcepub const TYPE_VENDOR: Self
pub const TYPE_VENDOR: Self
The request is a vendor-specific request.
Sourcepub const TYPE_RESERVED: Self
pub const TYPE_RESERVED: Self
Reserved.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u8) -> Self
pub const unsafe fn from_bits_unchecked(bits: u8) -> Self
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.