embassy-usb-driver

Crates

git

Versions

default

Flavors

SetupPacket

Struct SetupPacket 

#[repr(C)]
pub struct SetupPacket { pub request_type: RequestType, pub request: u8, pub value: u16, pub index: u16, pub length: u16, }
USB Control Setup Packet

Fields

request_type: RequestType

Request characteristics: direction, type, recipient. See RequestType type for details. Called bmRequestType in USB spec (Table 9-2).

request: u8

Request code. See Table 9-3 of USB spec for standard ones. Called bRequest in USB spec (Table 9-2).

value: u16

Use depending on request field. Called wValue in USB spec (Table 9-2).

index: u16

Use depending on request field. Called wIndex in USB spec (Table 9-2).

length: u16

Number of bytes to transfer in data stage if there is one. Called wLength in USB spec (Table 9-2).

Implementations

Source

impl SetupPacket

pub fn as_bytes(&self) -> &[u8]

Get a reference to the underlying bytes of the setup packet.